@@ -706,90 +706,6 @@ class NpmJs(metaclass=jsii.JSIIMeta, jsii_type="construct-hub.sources.NpmJs"):
 
         return typing.cast(aws_cdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricRemainingTime", [opts]))
 
-    @jsii.member(jsii_name="metricStagingFailureCount")
-    def metric_staging_failure_count(
-        self,
-        *,
-        account: typing.Optional[builtins.str] = None,
-        color: typing.Optional[builtins.str] = None,
-        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
-        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        label: typing.Optional[builtins.str] = None,
-        period: typing.Optional[aws_cdk.core.Duration] = None,
-        region: typing.Optional[builtins.str] = None,
-        statistic: typing.Optional[builtins.str] = None,
-        unit: typing.Optional[aws_cdk.aws_cloudwatch.Unit] = None,
-    ) -> aws_cdk.aws_cloudwatch.Metric:
-        '''(experimental) The total count of staging failures.
-
-        :param account: Account which this metric comes from. Default: - Deployment account.
-        :param color: The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
-        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
-        :param dimensions_map: Dimensions of the metric. Default: - No dimensions.
-        :param label: Label for this metric when added to a Graph in a Dashboard. Default: - No label
-        :param period: The period over which the specified statistic is applied. Default: Duration.minutes(5)
-        :param region: Region which this metric comes from. Default: - Deployment region.
-        :param statistic: What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
-        :param unit: Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream
-
-        :stability: experimental
-        '''
-        opts = aws_cdk.aws_cloudwatch.MetricOptions(
-            account=account,
-            color=color,
-            dimensions=dimensions,
-            dimensions_map=dimensions_map,
-            label=label,
-            period=period,
-            region=region,
-            statistic=statistic,
-            unit=unit,
-        )
-
-        return typing.cast(aws_cdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricStagingFailureCount", [opts]))
-
-    @jsii.member(jsii_name="metricStagingTime")
-    def metric_staging_time(
-        self,
-        *,
-        account: typing.Optional[builtins.str] = None,
-        color: typing.Optional[builtins.str] = None,
-        dimensions: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
-        dimensions_map: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        label: typing.Optional[builtins.str] = None,
-        period: typing.Optional[aws_cdk.core.Duration] = None,
-        region: typing.Optional[builtins.str] = None,
-        statistic: typing.Optional[builtins.str] = None,
-        unit: typing.Optional[aws_cdk.aws_cloudwatch.Unit] = None,
-    ) -> aws_cdk.aws_cloudwatch.Metric:
-        '''(experimental) The average time it took to stage a package to S3.
-
-        :param account: Account which this metric comes from. Default: - Deployment account.
-        :param color: The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
-        :param dimensions: (deprecated) Dimensions of the metric. Default: - No dimensions.
-        :param dimensions_map: Dimensions of the metric. Default: - No dimensions.
-        :param label: Label for this metric when added to a Graph in a Dashboard. Default: - No label
-        :param period: The period over which the specified statistic is applied. Default: Duration.minutes(5)
-        :param region: Region which this metric comes from. Default: - Deployment region.
-        :param statistic: What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
-        :param unit: Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream
-
-        :stability: experimental
-        '''
-        opts = aws_cdk.aws_cloudwatch.MetricOptions(
-            account=account,
-            color=color,
-            dimensions=dimensions,
-            dimensions_map=dimensions_map,
-            label=label,
-            period=period,
-            region=region,
-            statistic=statistic,
-            unit=unit,
-        )
-
-        return typing.cast(aws_cdk.aws_cloudwatch.Metric, jsii.invoke(self, "metricStagingTime", [opts]))
-
     @jsii.member(jsii_name="metricUnprocessableEntity")
     def metric_unprocessable_entity(
         self,
